@@ -93,6 +93,7 @@ home = expanduser("~")
 cwd = os.getcwd()
 username = getpass.getuser()
 if os.path.isfile(args.pem_file) and os.access(args.pem_file, os.R_OK):
+    print "CWD="+cwd
     pem_file_path=cwd+'/'+args.pem_file
     os.chmod(pem_file_path,0777)
     print pem_file_path+" exists and is readable"
@@ -114,7 +115,6 @@ with open(pem_file_path,'rb') as f:
     pemfile = f.read()
 print pemfile
 
-username = getpass.getuser();
 http = httplib2.Http(disable_ssl_certificate_validation=True)
 http.follow_redirects = False
 url = "https://localhost/request?client_id=" + client_id \
@@ -227,27 +227,50 @@ upload(url,pem_file_path,bearer)
 
 time.sleep( 1 )
 
-data = {'cmd': [['cmd','mv /tmp/'+args.pem_file+
-                 ' '+os.getcwd()],
-                ['cmd','mv /tmp/'+credentials_file+
-                 ' '+os.getcwd()],
-                ['cwd',os.getcwd()],
-                ['cmd','chmod 400 '+args.pem_file],
+data = {'cmd': [['cmd','echo $HOME'],
+                ['cmd','echo $USER'],
+                ['cmd','echo $HOSTNAME'],
+                ['cmd','mkdir -pv $HOME/FullAutoAPI']]}
+headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+result = json.loads(content)
+result = json.loads(result['result'])
+homedir=result[0][0]
+remuser=result[1][0]
+hostnam=result[2][0]
+lochost=socket.gethostname()
+
+if hostnam == lochost:
+   remuser=username
+   homedir=home
+
+time.sleep( 1 )
+
+mvpem=args.pem_file
+if re.search(' ',args.pem_file):
+    mvpem="'"+mvpem+"'"
+mvcre=credentials_file
+if re.search(' ',args.pem_file):
+    mvcre="'"+mvcre+"'"
+    
+data = {'cmd': [['cmd','mv /tmp/'+mvpem+
+                 ' '+homedir+'/FullAutoAPI'],
+                ['cmd','mv /tmp/'+mvcre+
+                 ' '+homedir+'/FullAutoAPI'],
+                ['cwd',homedir+'/FullAutoAPI'],
+                ['cmd','chmod 400 '+mvpem],
                 ['cmd',new_sg],
                 ['cmd',ingress]]}
-                #['cmd',new_inst]]}
 headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
 result = json.loads(content)
 result = json.loads(result['result'])
 from pprint import pprint
-#pprint(result)
-#sys.exit()
 sec_group_id=''
 if re.search('already exists for VPC',result[4][0]):
    get_sec='aws ec2 describe-security-groups --group-names DockerSecurityGroup'
    data = {'cmd': [['cmd',get_sec]]}
    time.sleep( 1 )
-   headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+   headerz, content = http.request(url, "POST", body=dumps(data), \
+      headers=headers)
    result = json.loads(content)
    result = json.loads(result['result'])
    result = json.loads(result[0][0])
@@ -272,7 +295,8 @@ result = json.loads(content)
 result = json.loads(result['result'])
 result = json.loads(result[0][0])
 imagid = result['Images'][0]['ImageId']
-keynam = re.sub(r'\.pem$','',args.pem_file)
+keynam = re.sub(r' [(]\d+[)]','',args.pem_file)
+keynam = re.sub(r'\.pem$','',keynam)
 new_inst = 'aws ec2 run-instances --image-id '+imagid+' --count=1 ' + \
            '--key-name ' + keynam + ' ' + \
            '--instance-type=t2.micro --security-group-ids ' + \
@@ -282,7 +306,6 @@ headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
 result = json.loads(content)
 result = json.loads(result['result'])
 result = json.loads(result[0][0])
-print result
 docker_ip=result['Instances'][0]['PrivateIpAddress']
 instance_id=result['Instances'][0]['InstanceId']
 loop = 1
@@ -299,16 +322,17 @@ while loop == 1: # This creates an infinite loop
       break
 print '==================='
 print docker_ip
-data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':os.getcwd()+'/'+args.pem_file,'noretry':'1'}]]}
+print "USERNAME="+remuser+'/'+args.pem_file
+data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':'/home/'+remuser+'/FullAutoAPI/'+args.pem_file,'noretry':'1'}]]}
 time.sleep( 1 )
 docker_server1='';
 print "\nGoing to Attempt to Connect to new Docker Server via ssh . . .\n"
 while loop == 1: # This creates an infinite loop
-   headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
+   headerz, content = http.request(url, "POST", body=dumps(data), \
+      headers=headers)
    result = json.loads(content)
    result = json.loads(result['result'])
    if re.search('Connection timed out|Connection refused',result[0][1]):
-      #print result[0][1]
       print "\n   Waiting for sshd service to start . . .\n"
       time.sleep( 3 )
       continue
@@ -331,7 +355,10 @@ headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
 result = json.loads(content)
 result = json.loads(result['result'])
 print result
-data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':os.getcwd()+'/'+args.pem_file,'noretry':'1'}]]}
+print "USERNAME="+remuser+'/'+args.pem_file
+data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user', \
+   'identityfile':'/home/'+remuser+'/FullAutoAPI/'+
+   args.pem_file,'noretry':'1'}]]}
 time.sleep( 1 )
 docker_server1='';
 while loop == 1: # This creates an infinite loop
